+++
title = "Taxonomy weights and page weight (auto) 2"
tags = ["weight", "taxonomy-weight", "auto", "page-weight", "tags", "categories"]
draft = false
categories_weight = 5002
weight = 5002
tags_weight = 5002
+++

The page weight does not have to be specified as the very first weight
if using the `:page` keyword before the weight value.
